summary refs log tree commit diff stats
path: root/src/common/plugin.h
diff options
context:
space:
mode:
authorBerke Viktor <bviktor@hexchat.org>2012-10-30 08:42:48 +0100
committerBerke Viktor <bviktor@hexchat.org>2012-10-30 08:42:48 +0100
commite681eafa78262d0c177832d67900687f2c938081 (patch)
tree5668476e046c505b9f3fcc8c53b6e0971c146978 /src/common/plugin.h
parent97dc13fde70810abf07985f45ac459560eae6e96 (diff)
Rebranding for the rest of plugin*
Diffstat (limited to 'src/common/plugin.h')
-rw-r--r--src/common/plugin.h102
1 files changed, 51 insertions, 51 deletions
diff --git a/src/common/plugin.h b/src/common/plugin.h
index 8b2b00dc..e61b5111 100644
--- a/src/common/plugin.h
+++ b/src/common/plugin.h
@@ -2,121 +2,121 @@
 #define HEXCHAT_COMMONPLUGIN_H
 
 #ifdef PLUGIN_C
-struct _xchat_plugin
+struct _hexchat_plugin
 {
 	/* Keep these in sync with hexchat-plugin.h */
 	/* !!don't change the order, to keep binary compat!! */
-	xchat_hook *(*xchat_hook_command) (xchat_plugin *ph,
+	hexchat_hook *(*hexchat_hook_command) (hexchat_plugin *ph,
 		    const char *name,
 		    int pri,
 		    int (*callback) (char *word[], char *word_eol[], void *user_data),
 		    const char *help_text,
 		    void *userdata);
-	xchat_hook *(*xchat_hook_server) (xchat_plugin *ph,
+	hexchat_hook *(*hexchat_hook_server) (hexchat_plugin *ph,
 		   const char *name,
 		   int pri,
 		   int (*callback) (char *word[], char *word_eol[], void *user_data),
 		   void *userdata);
-	xchat_hook *(*xchat_hook_print) (xchat_plugin *ph,
+	hexchat_hook *(*hexchat_hook_print) (hexchat_plugin *ph,
 		  const char *name,
 		  int pri,
 		  int (*callback) (char *word[], void *user_data),
 		  void *userdata);
-	xchat_hook *(*xchat_hook_timer) (xchat_plugin *ph,
+	hexchat_hook *(*hexchat_hook_timer) (hexchat_plugin *ph,
 		  int timeout,
 		  int (*callback) (void *user_data),
 		  void *userdata);
-	xchat_hook *(*xchat_hook_fd) (xchat_plugin *ph,
+	hexchat_hook *(*hexchat_hook_fd) (hexchat_plugin *ph,
 		   int fd,
 		   int flags,
 		   int (*callback) (int fd, int flags, void *user_data),
 		   void *userdata);
-	void *(*xchat_unhook) (xchat_plugin *ph,
-	      xchat_hook *hook);
-	void (*xchat_print) (xchat_plugin *ph,
+	void *(*hexchat_unhook) (hexchat_plugin *ph,
+	      hexchat_hook *hook);
+	void (*hexchat_print) (hexchat_plugin *ph,
 	     const char *text);
-	void (*xchat_printf) (xchat_plugin *ph,
+	void (*hexchat_printf) (hexchat_plugin *ph,
 	      const char *format, ...);
-	void (*xchat_command) (xchat_plugin *ph,
+	void (*hexchat_command) (hexchat_plugin *ph,
 	       const char *command);
-	void (*xchat_commandf) (xchat_plugin *ph,
+	void (*hexchat_commandf) (hexchat_plugin *ph,
 		const char *format, ...);
-	int (*xchat_nickcmp) (xchat_plugin *ph,
+	int (*hexchat_nickcmp) (hexchat_plugin *ph,
 	       const char *s1,
 	       const char *s2);
-	int (*xchat_set_context) (xchat_plugin *ph,
-		   xchat_context *ctx);
-	xchat_context *(*xchat_find_context) (xchat_plugin *ph,
+	int (*hexchat_set_context) (hexchat_plugin *ph,
+		   hexchat_context *ctx);
+	hexchat_context *(*hexchat_find_context) (hexchat_plugin *ph,
 		    const char *servname,
 		    const char *channel);
-	xchat_context *(*xchat_get_context) (xchat_plugin *ph);
-	const char *(*xchat_get_info) (xchat_plugin *ph,
+	hexchat_context *(*hexchat_get_context) (hexchat_plugin *ph);
+	const char *(*hexchat_get_info) (hexchat_plugin *ph,
 		const char *id);
-	int (*xchat_get_prefs) (xchat_plugin *ph,
+	int (*xchat_get_prefs) (hexchat_plugin *ph,
 		 const char *name,
 		 const char **string,
 		 int *integer);
-	xchat_list * (*xchat_list_get) (xchat_plugin *ph,
+	hexchat_list * (*hexchat_list_get) (hexchat_plugin *ph,
 		const char *name);
-	void (*xchat_list_free) (xchat_plugin *ph,
-		 xchat_list *xlist);
-	const char * const * (*xchat_list_fields) (xchat_plugin *ph,
+	void (*hexchat_list_free) (hexchat_plugin *ph,
+		 hexchat_list *xlist);
+	const char * const * (*hexchat_list_fields) (hexchat_plugin *ph,
 		   const char *name);
-	int (*xchat_list_next) (xchat_plugin *ph,
-		 xchat_list *xlist);
-	const char * (*xchat_list_str) (xchat_plugin *ph,
-		xchat_list *xlist,
+	int (*hexchat_list_next) (hexchat_plugin *ph,
+		 hexchat_list *xlist);
+	const char * (*hexchat_list_str) (hexchat_plugin *ph,
+		hexchat_list *xlist,
 		const char *name);
-	int (*xchat_list_int) (xchat_plugin *ph,
-		xchat_list *xlist,
+	int (*hexchat_list_int) (hexchat_plugin *ph,
+		hexchat_list *xlist,
 		const char *name);
-	void * (*xchat_plugingui_add) (xchat_plugin *ph,
+	void * (*hexchat_plugingui_add) (hexchat_plugin *ph,
 		     const char *filename,
 		     const char *name,
 		     const char *desc,
 		     const char *version,
 		     char *reserved);
-	void (*xchat_plugingui_remove) (xchat_plugin *ph,
+	void (*hexchat_plugingui_remove) (hexchat_plugin *ph,
 			void *handle);
-	int (*xchat_emit_print) (xchat_plugin *ph,
+	int (*hexchat_emit_print) (hexchat_plugin *ph,
 			const char *event_name, ...);
-	void *(*xchat_read_fd) (xchat_plugin *ph);
-	time_t (*xchat_list_time) (xchat_plugin *ph,
-		xchat_list *xlist,
+	void *(*xchat_read_fd) (hexchat_plugin *ph);
+	time_t (*hexchat_list_time) (hexchat_plugin *ph,
+		hexchat_list *xlist,
 		const char *name);
-	char *(*xchat_gettext) (xchat_plugin *ph,
+	char *(*hexchat_gettext) (hexchat_plugin *ph,
 		const char *msgid);
-	void (*xchat_send_modes) (xchat_plugin *ph,
+	void (*hexchat_send_modes) (hexchat_plugin *ph,
 		  const char **targets,
 		  int ntargets,
 		  int modes_per_line,
 		  char sign,
 		  char mode);
-	char *(*xchat_strip) (xchat_plugin *ph,
+	char *(*hexchat_strip) (hexchat_plugin *ph,
 	     const char *str,
 	     int len,
 	     int flags);
-	void (*xchat_free) (xchat_plugin *ph,
+	void (*hexchat_free) (hexchat_plugin *ph,
 	    void *ptr);
-	int (*xchat_pluginpref_set_str) (xchat_plugin *ph,
+	int (*hexchat_pluginpref_set_str) (hexchat_plugin *ph,
 		const char *var,
 		const char *value);
-	int (*xchat_pluginpref_get_str) (xchat_plugin *ph,
+	int (*hexchat_pluginpref_get_str) (hexchat_plugin *ph,
 		const char *var,
 		char *dest);
-	int (*xchat_pluginpref_set_int) (xchat_plugin *ph,
+	int (*hexchat_pluginpref_set_int) (hexchat_plugin *ph,
 		const char *var,
 		int value);
-	int (*xchat_pluginpref_get_int) (xchat_plugin *ph,
+	int (*hexchat_pluginpref_get_int) (hexchat_plugin *ph,
 		const char *var);
-	int (*xchat_pluginpref_delete) (xchat_plugin *ph,
+	int (*hexchat_pluginpref_delete) (hexchat_plugin *ph,
 		const char *var);
-	int (*xchat_pluginpref_list) (xchat_plugin *ph,
+	int (*hexchat_pluginpref_list) (hexchat_plugin *ph,
 		char *dest);
-	void *(*xchat_dummy4) (xchat_plugin *ph);
-	void *(*xchat_dummy3) (xchat_plugin *ph);
-	void *(*xchat_dummy2) (xchat_plugin *ph);
-	void *(*xchat_dummy1) (xchat_plugin *ph);
+	void *(*xchat_dummy4) (hexchat_plugin *ph);
+	void *(*xchat_dummy3) (hexchat_plugin *ph);
+	void *(*xchat_dummy2) (hexchat_plugin *ph);
+	void *(*xchat_dummy1) (hexchat_plugin *ph);
 	/* PRIVATE FIELDS! */
 	void *handle;		/* from dlopen */
 	char *filename;	/* loaded from */
@@ -124,8 +124,8 @@ struct _xchat_plugin
 	char *desc;
 	char *version;
 	session *context;
-	void *deinit_callback;	/* pointer to xchat_plugin_deinit */
-	unsigned int fake:1;		/* fake plugin. Added by xchat_plugingui_add() */
+	void *deinit_callback;	/* pointer to hexchat_plugin_deinit */
+	unsigned int fake:1;		/* fake plugin. Added by hexchat_plugingui_add() */
 	unsigned int free_strings:1;		/* free name,desc,version? */
 };
 #endif